@@ -1,4 +1,4 @@
-#  Copyright 2023 Commonwealth Scientific and Industrial Research
+#  Copyright © 2018-2025 Commonwealth Scientific and Industrial Research
 #  Organisation (CSIRO) ABN 41 687 119 230.
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
@@ -131,11 +131,11 @@ pathling_examples <- function(...) {
 #'
 #' @export
 #' 
-#' @examplesIf pathling_is_spark_installed()
-#' pc <- pathling_connect()
+#' @examples \dontrun{
 #' pathling_example_resource(pc, 'Condition')
-#' pathling_disconnect(pc)
+#' }
 pathling_example_resource <- function(pc, resource_name) {
-  pc %>% pathling_spark() %>% 
-      sparklyr::spark_read_parquet(pathling_examples("parquet" , paste0(resource_name, ".parquet")))
+  pc %>%
+      pathling_spark() %>%
+      sparklyr::spark_read_parquet(pathling_examples("parquet", paste0(resource_name, ".parquet")))
 }
